@@ -37,14 +37,15 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <X11/extensions/SGIStereo.h> /* aro */
 #endif /* SGI_STEREO */
 
+#include "globals.h"
 #include "bbox.h"
 #include "bonds.h"
 #include "defs.h"
 #include "draw.h"
-#include "globals.h"
 #include "view.h"
 
 #include "gl_funcs.h"
+#include "gl2ps.h"
 
 /* Function prototypes */
 
@@ -62,6 +63,7 @@ void gl_render_bonds (void);
 void gl_render_hbonds (void);
 void gl_render_vectors (void);
 void gl_set_perspective (void);
+double get_smallest_cov_rad (void);
 void gl_update_near_and_far (void);
 double mod_of_vec (double *);
 Boolean mouse_motion_p (void);
@@ -182,28 +184,27 @@ void gl_render (void)
     
       if ((! mouse_motion_p ()) || (! outline_mode_p ()))
         {
-
           if (gl_use_lighting)
             {
-              glEnable (GL_LIGHTING);
               gluQuadricNormals (gl_quadric, GLU_SMOOTH);
             }
           else
             {
-              glDisable (GL_LIGHTING);
               gluQuadricNormals (gl_quadric, GLU_NONE);
             }
+          gluQuadricDrawStyle (gl_quadric, GLU_FILL);
           
           glEnable (GL_DEPTH_TEST);
           glEnable (GL_COLOR_MATERIAL);
-          
-          gluQuadricDrawStyle (gl_quadric, GLU_FILL);
+
+          glDisable (GL_LIGHTING);
+          if (bbox_flag && (no_atoms > 0)) gl_render_bbox ();
+          if (gl_use_lighting) glEnable (GL_LIGHTING);
           
           gl_render_atoms ();
           gl_render_bonds ();
           gl_render_hbonds ();
           gl_render_vectors ();
-          if (bbox_flag && (no_atoms > 0)) gl_render_bbox ();
         }
       else
         {
@@ -253,32 +254,30 @@ void gl_render (void)
 
   if ((! mouse_motion_p ()) || (! outline_mode_p ()))
     {
-      
       if (gl_use_lighting)
         {
-          glEnable (GL_LIGHTING);
           gluQuadricNormals (gl_quadric, GLU_SMOOTH);
         }
       else
         {
-          glDisable (GL_LIGHTING);
           gluQuadricNormals (gl_quadric, GLU_NONE);
         }
+      gluQuadricDrawStyle (gl_quadric, GLU_FILL);
 
       glEnable (GL_DEPTH_TEST);
       glEnable (GL_COLOR_MATERIAL);
 
-      gluQuadricDrawStyle (gl_quadric, GLU_FILL);
+      glDisable (GL_LIGHTING);
+      if (bbox_flag && (no_atoms > 0)) gl_render_bbox ();
+      if (gl_use_lighting) glEnable (GL_LIGHTING);
 
       gl_render_atoms ();
       gl_render_bonds ();
       gl_render_hbonds ();
       gl_render_vectors ();
-      if (bbox_flag && (no_atoms > 0)) gl_render_bbox ();
     }
   else
     {
-
       glDisable (GL_LIGHTING);
       glDisable (GL_DEPTH_TEST);
       glDisable (GL_COLOR_MATERIAL);
@@ -367,6 +366,7 @@ void StereoProjection(float left, float right, float bottom, float top,
 void gl_render_atoms (void)
 {
   void gl_render_atom (int);
+  int get_gl_render_type (void);
 
   int i;
 
@@ -393,7 +393,6 @@ void gl_render_atom (int i)
 {
   int j;
 
-  double get_smallest_cov_rad (void);
   double line_width, atom_size;
 
   char string[16]="", sub_string[8]="", *labels = "ABCD";
@@ -610,7 +609,22 @@ void gl_render_atom (int i)
 
 void gl_render_bbox (void)
 {
+  GLfloat line_width = 2.0;
+
+  glColor3f (0.7, 0.7, 0.7);
+  glDepthMask (GL_FALSE);
+
+  gl_render_bbox_face (0, 1, 3, 2);
+  gl_render_bbox_face (4, 5, 7, 6);
+  gl_render_bbox_face (0, 2, 6, 4);
+  gl_render_bbox_face (1, 3, 7, 5);
+  gl_render_bbox_face (0, 1, 5, 4);
+  gl_render_bbox_face (2, 3, 7, 6);
+
+  glDepthMask (GL_TRUE);
+
   glColor3f (0.0, 0.0, 0.0);
+  glLineWidth (line_width);
 
   gl_render_bbox_line (0, 1);
   gl_render_bbox_line (0, 2);
@@ -624,21 +638,11 @@ void gl_render_bbox (void)
   gl_render_bbox_line (4, 6);
   gl_render_bbox_line (5, 7);
   gl_render_bbox_line (6, 7);
-
-/*   gl_render_bbox_face (0, 1, 3, 2); */
-/*   gl_render_bbox_face (4, 5, 7, 6); */
-/*   gl_render_bbox_face (0, 2, 6, 4); */
-/*   gl_render_bbox_face (1, 3, 7, 5); */
-/*   gl_render_bbox_face (0, 1, 5, 4); */
-/*   gl_render_bbox_face (2, 3, 7, 6); */
 }
 
 
 void gl_render_bbox_line (int i, int j)
 {
-
-  glLineWidth (2);
-
   glBegin (GL_LINES);
   glVertex3f (bbox.v[i][0], bbox.v[i][1], bbox.v[i][2]);
   glVertex3f (bbox.v[j][0], bbox.v[j][1], bbox.v[j][2]);
@@ -647,19 +651,12 @@ void gl_render_bbox_line (int i, int j)
 
 void gl_render_bbox_face (int i, int j, int k, int l)
 {
-  glEnable (GL_BLEND);
-  glDepthMask (GL_FALSE);       /* read-only depth buffer */
-  glBlendFunc (GL_ONE_MINUS_SRC_ALPHA, GL_ONE);
-
-  glBegin (GL_POLYGON);        
+  glBegin (GL_POLYGON);
   glVertex3f (bbox.v[i][0], bbox.v[i][1], bbox.v[i][2]);
   glVertex3f (bbox.v[j][0], bbox.v[j][1], bbox.v[j][2]);
   glVertex3f (bbox.v[k][0], bbox.v[k][1], bbox.v[k][2]);
   glVertex3f (bbox.v[l][0], bbox.v[l][1], bbox.v[l][2]);
   glEnd();
-
-  glDepthMask (GL_TRUE);
-  glDisable (GL_BLEND);
 }
 
 
@@ -695,7 +692,6 @@ void gl_render_bond (int i,
                      int j)
 {
   enum render_stereo_types get_gl_render_stereo(void);/* aro */
-  double get_smallest_cov_rad (void);
   void update_canvas_bond_points (int, int, Boolean, double);
 
   int k;
@@ -950,12 +946,19 @@ void gl_render_hbond (int i,
 
 double gl_get_rendered_atom_size (int i)
 {
+  int get_gl_render_type (void);
   double atom_size = 0;
 
   /* Work out the size the atom is going to be rendered at taking into
      account the drawing mode (BALL_AND_STICK or TUBES) and whether or
      not atoms and bonds are being displayed */
 
+  /* We need this for bounding box calculation; it is a duplication of
+     effort when called from gl_render_atom. */
+
+  gl_current_render_type = (atoms[i].gl_render_type == DEFAULT) ?
+    get_gl_render_type () : atoms[i].gl_render_type;
+
   if ((gl_current_render_type == BALL_AND_STICK) || (! gl_use_lighting))
     {
       if (atom_flag)
